@@ -1,7 +1,7 @@
 package App::cpm::CircularDependency;
 use strict;
 use warnings;
-our $VERSION = '0.954';
+our $VERSION = '0.955';
 
 {
     package
@@ -80,7 +80,7 @@ sub detect {
             $result{$distfile} = [$detected->values, $distfile];
         }
     }
-    return %result ? \%result : undef;
+    return \%result;
 }
 
 sub _detect {
